ENDPOINT = 'http://47.238.228.17:10010'
NOTIFY_AUTH_TOKEN = 'SAIS_NOTIFY_AUTH_TOKEN'

SAIS_ROBOT_NAME = 'sais-post-robot'
NOTIFY_SERVICE_NOTIFY_TYPE_FEISHU = 'feishu'
NOTIFY_SERVICE_NOTIFY_TYPE_FEISHU_GROUP = 'feishu_group'
LOGGER_NAME = 'sais.notify'
